@@ -1,7 +1,9 @@
 import gzip
 import os
-from io import BytesIO
+from io import BytesIO, StringIO
 import polars as pl
+import requests
+
 from cameo_claw.net import requests_get
 
 import warnings
@@ -37,11 +39,20 @@ def write_gzip(bytesio, path):
         f.write(bytesio.getvalue())
 
 
-def read_csv_distinct(bytes1, lst_distinct_column):
+def pl_read_csv_distinct(bytes1, lst_distinct_column):
     df = pl.read_csv(bytes1, infer_schema_length=20000)
     df = df.distinct(subset=lst_distinct_column)
     return df
 
 
-def read_csv_str(bytes1):
+def pl_read_csv_str(bytes1):
     return pl.read_csv(bytes1, infer_schema_length=0).with_columns(pl.all().cast(pl.Int32, strict=False))
+
+
+def pd_read_csv(bytes1):
+    df = None
+    if bytes1[0:2] == b'\x1f\x8b':
+        df = pd.read_csv(BytesIO(bytes1), compression='gzip')
+    else:
+        df = pd.read_csv(BytesIO(bytes1))
+    return df
